pub struct Bool8Field { /* private fields */ }Expand description
A helper to construct new Bool8 fields (arrow.bool8)
This extension type can be used with overwrites in schema tracing:
#[derive(Deserialize)]
struct Record {
int_field: i32,
nested: Nested,
}
#[derive(Deserialize)]
struct Nested {
bool_field: bool,
}
let tracing_options = TracingOptions::default()
.overwrite("nested.bool_field", Bool8Field::new("bool_field"))?;
let schema = SerdeArrowSchema::from_type::<Record>(tracing_options)?;It can also be converted to a arrow Field for manual schema manipulation.
Implementations